

.. .. _dwls_api:

.. DimensionWithLinearSpacing
.. ^^^^^^^^^^^^^^^^^^^^^^^^^^

.. .. currentmodule:: csdmpy._independent_variables
.. .. autoclass:: DimensionWithLinearSpacing
..     :show-inheritance:

..     .. rubric:: Attributes Summary

..     .. autosummary::
..         ~DimensionWithLinearSpacing.sampling_interval
..         ~DimensionWithLinearSpacing.coordinates


..     .. rubric:: Attributes Documentation

..     .. autoattribute:: sampling_interval
..     .. autoattribute:: coordinates
